Data Modules
=============

This module provides data module implementations for concept-based datasets.

.. currentmodule:: torch_concepts.data.datamodules

Summary
-------

**DataModule Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   BnLearnDataModule


Class Documentation
-------------------

.. autoclass:: torch_concepts.data.datamodules.BnLearnDataModule
   :members:
   :undoc-members:
   :show-inheritance:
